#!/usr/bin/env python3
# -*- coding: utf-8, vim: expandtab:ts=4 -*-

"""
sono-board
Copyright (C) 2021  Sono Project

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.
"""

# imports: library
from argparse import ArgumentParser
import configparser
import logging
import logging.config
import pkg_resources
import sys
import tkinter  # no underscore, lowercase 't' for V3.0 and later
from tkinter import ttk

# imports: project
from sono_board.config import Config
from sono_board import sound
from sono_board.version import __version__


def main() -> None:

    logger_config_name = 'data/logger.ini'

    if not pkg_resources.resource_exists(__name__, logger_config_name):
        logging.error('logger config does not exist')
        return

    logger_config = pkg_resources.resource_stream(__name__, logger_config_name)
    logger_config_str = logger_config.read().decode('UTF-8')
    logger_config_parser = configparser.ConfigParser()
    logger_config_parser.read_string(logger_config_str)
    logging.config.fileConfig(logger_config_parser)

    logging.info('Sono Board')
    logging.info('----------')

    parser = ArgumentParser(prog='sono-board')

    parser.add_argument('--version',
                        help='Display version',
                        action='store_const', const=True, default=False,
                        dest='version')

    parser.add_argument('--board',
                        help='Name of the board config',
                        action='store', default=None,
                        dest='board_name')

    args = parser.parse_args(sys.argv[1:])

    if args.version:
        print(f'Sono Board {__version__}')
        return

    config = Config(__file__)

    if args.board_name is None:
        logging.warning('No board specified. See the --board option.')
        logging.warning('Exiting.')
        return

    config.load(args.board_name)

    root = tkinter.Tk()
    frm = ttk.Frame(root, padding=10)
    frm.grid()

    ttk.Label(frm, text=config.title).grid(column=0, row=0)
    ttk.Button(frm, text="Quit", command=root.destroy).grid(column=1, row=0)

    for index, sound_item in enumerate(config.sound_items):
        sound_item_path = config.data_path_board(sound_item.filename)

        ttk.Button(frm,
                   text=sound_item.text,
                   command=sound.load_sound(sound_item_path).play
                   ).grid(column=0,
                          row=index + 1)

    root.mainloop()

    sound.deinit()


if __name__ == '__main__':
    main()
